import { Metadata } from "next";
import { cn } from "@/lib/utils";

import "@/styles/globals.css";
import { Inter as FontSans } from "next/font/google";
import Header from "@/components/Header";

export const metadata: Metadata = {
  title: {
    template: "%s | MYP",
    default: "MYP",
  },
  description:
    "MYP (Manage your Printer) ist eine 3D-Drucker Reservierungsplattform entwickelt für die TBA Berlin (W040).",
  icons: [{ rel: "icon", url: "/favicon.ico" }],
};

const fontSans = FontSans({
  subsets: ["latin"],
  variable: "--font-sans",
});

interface RootLayoutProps {
  children: React.ReactNode;
}

export default function RootLayout({ children }: RootLayoutProps) {
  return (
    <html lang="en" suppressHydrationWarning>
      <head />
      <body
        className={cn(
          "min-h-screen bg-background font-sans antialiased",
          fontSans.variable,
        )}
      >
        <Header />
        <main className="flex justify-center px-96 py-8">{children}</main>
      </body>
    </html>
  );
}
